@@ -1,5 +1,5 @@
 #
-# $Id: Perl6.pm 24936 2009-01-17 10:37:58Z azawawi $
+# $Id: Perl6.pm 25022 2009-01-25 17:23:58Z azawawi $
 #
 package Syntax::Highlight::Perl6;
 
@@ -24,13 +24,13 @@ use STD;
 
 # exports and version
 our @EXPORT_OK = qw();
-our $VERSION = '0.035';
+our $VERSION = '0.036';
 
 # filename constants
 Readonly my $FILE_CSS    => 'p6_style.css';
 Readonly my $FILE_ANSI   => 'p6_style.ansi';
 Readonly my $FILE_JS     => 'p6_style.js';
-Readonly my $FILE_JQUERY => 'jquery-1.3.min.js';
+Readonly my $FILE_JQUERY => 'jquery-1.3.1.min.js';
 Readonly my $FILE_P6_VIM => 'perl6.vim';
 
 # These are needed for redspans
